aboutsummaryrefslogtreecommitdiff
path: root/ports/vtk
diff options
context:
space:
mode:
authormartin-s <webmaster@macside.net>2017-11-05 19:13:16 +0100
committermartin-s <webmaster@macside.net>2017-11-05 19:13:16 +0100
commitd5a7da6bcb92b551d6f8a9a321deb063f6632dbc (patch)
tree9dfef57f1fb3611bde577cab7b9dee9411ffb041 /ports/vtk
parentc6d69fac625706c52fc8e48615bc0c6d7b8dad25 (diff)
parent330b8d8bab6a3d07165bf7c05fea09a8e0d56348 (diff)
downloadvcpkg-d5a7da6bcb92b551d6f8a9a321deb063f6632dbc.tar.gz
vcpkg-d5a7da6bcb92b551d6f8a9a321deb063f6632dbc.zip
Merge branch 'master' of https://github.com/Microsoft/vcpkg into patch-vs2013
# Conflicts: # scripts/cmake/vcpkg_configure_cmake.cmake # toolsrc/src/vcpkg/vcpkgpaths.cpp
Diffstat (limited to 'ports/vtk')
-rw-r--r--ports/vtk/CONTROL20
-rw-r--r--ports/vtk/portfile.cmake38
2 files changed, 50 insertions, 8 deletions
diff --git a/ports/vtk/CONTROL b/ports/vtk/CONTROL
index 22d1b1376..d30e61506 100644
--- a/ports/vtk/CONTROL
+++ b/ports/vtk/CONTROL
@@ -1,4 +1,20 @@
Source: vtk
-Version: 8.0.0-3
+Version: 8.0.1-1
Description: Software system for 3D computer graphics, image processing, and visualization
-Build-Depends: zlib, libpng, tiff, libxml2, jsoncpp, glew, freetype, expat, hdf5, qt5, msmpi, libjpeg-turbo, proj4, lz4, libtheora, libharu
+Build-Depends: zlib, libpng, tiff, libxml2, jsoncpp, glew, freetype, expat, hdf5, libjpeg-turbo, proj4, lz4, libtheora, libharu
+
+Feature: openvr
+Description: OpenVR functionality for VTK
+Build-Depends: sdl2, openvr
+
+Feature: qt
+Description: Qt functionality for VTK
+Build-Depends: qt5
+
+Feature: mpi
+Description: MPI functionality for VTK
+Build-Depends: msmpi
+
+Feature: python
+Description: Python functionality for VTK
+Build-Depends: python3
diff --git a/ports/vtk/portfile.cmake b/ports/vtk/portfile.cmake
index c5ea4c387..0a407e9ae 100644
--- a/ports/vtk/portfile.cmake
+++ b/ports/vtk/portfile.cmake
@@ -1,24 +1,44 @@
include(vcpkg_common_functions)
set(VTK_SHORT_VERSION "8.0")
-set(VTK_LONG_VERSION "${VTK_SHORT_VERSION}.0")
+set(VTK_LONG_VERSION "${VTK_SHORT_VERSION}.1")
vcpkg_from_github(
OUT_SOURCE_PATH SOURCE_PATH
REPO "Kitware/VTK"
REF "v${VTK_LONG_VERSION}"
- SHA512 1a328f24df0b1c40c623ae80c9d49f8b27570144b10af02aeed41b90b50b8d4e0dd83d1341961f6818cde36e2cd793c578ebc95a46950cebfc518f486f249791
+ SHA512 3a70fa704d791d21a1e2421e6799ccc8238da5bc1fc0ab1925fb7956ccaebb7748c452faba1e7f4a2eafbc8612ed644f46f84b0cb3fe16ce539a823165feb29f
HEAD_REF "master"
)
# =============================================================================
# Options: These should be set by feature-packages when they become available
-set(VTK_WITH_QT ON ) # IMPORTANT: if ON make sure `qt5` is listed as dependency in the CONTROL file
-set(VTK_WITH_MPI ON ) # IMPORTANT: if ON make sure `mpi` is listed as dependency in the CONTROL file
-set(VTK_WITH_PYTHON OFF) # IMPORTANT: if ON make sure `python3` is listed as dependency in the CONTROL file
+
+if ("qt" IN_LIST FEATURES)
+ set(VTK_WITH_QT ON ) # IMPORTANT: if ON make sure `qt5` is listed as dependency in the CONTROL file
+else()
+ set(VTK_WITH_QT OFF ) # IMPORTANT: if ON make sure `qt5` is listed as dependency in the CONTROL file
+endif()
+
+if ("mpi" IN_LIST FEATURES)
+ set(VTK_WITH_MPI ON ) # IMPORTANT: if ON make sure `mpi` is listed as dependency in the CONTROL file
+else()
+ set(VTK_WITH_MPI OFF ) # IMPORTANT: if ON make sure `mpi` is listed as dependency in the CONTROL file
+endif()
+
+if ("python" IN_LIST FEATURES)
+ set(VTK_WITH_PYTHON ON) # IMPORTANT: if ON make sure `python3` is listed as dependency in the CONTROL file
+else()
+ set(VTK_WITH_PYTHON OFF) # IMPORTANT: if ON make sure `python3` is listed as dependency in the CONTROL file
+endif()
+if("openvr" IN_LIST FEATURES)
+ set(VTK_WITH_OPENVR ON) # IMPORTANT: if ON make sure `OpenVR` is listed as dependency in the CONTROL file
+else()
+ set(VTK_WITH_OPENVR OFF)
+endif()
+
set(VTK_WITH_ALL_MODULES OFF) # IMPORTANT: if ON make sure `qt5`, `mpi`, `python3`, `ffmpeg`, `gdal`, `fontconfig`,
# `libmysql` and `atlmfc` are listed as dependency in the CONTROL file
-
# =============================================================================
# Apply patches to the source code
vcpkg_apply_patches(
@@ -78,6 +98,12 @@ if(VTK_WITH_PYTHON)
)
endif()
+if(VTK_WITH_OPENVR)
+ list(APPEND ADDITIONAL_OPTIONS
+ -DModule_vtkRenderingOpenVR=ON
+ )
+endif()
+
if(VTK_WITH_ALL_MODULES)
list(APPEND ADDITIONAL_OPTIONS
-DVTK_BUILD_ALL_MODULES=ON